@@ -20,7 +20,8 @@
 #include "signaturethread.h"
 #include "signature_p.h"
 
-#include <KDebug>
+#include "kget_debug.h"
+#include <qdebug.h>
 
 SignatureThread::SignatureThread(QObject *parent)
   : QThread(parent),
@@ -46,7 +47,7 @@ bool SignatureThread::isValid() const
 #endif //HAVE_QGPGME
 }
 
-void SignatureThread::verify(const KUrl &dest, const QByteArray &sig)
+void SignatureThread::verify(const QUrl &dest, const QByteArray &sig)
 {
     QMutexLocker locker(&m_mutex);
     m_dest.append(dest);
@@ -62,7 +63,7 @@ void SignatureThread::run()
 #ifdef HAVE_QGPGME
     while (!m_abort && m_dest.count()) {
         m_mutex.lock();
-        const KUrl dest = m_dest.takeFirst();
+        const QUrl dest = m_dest.takeFirst();
         const QByteArray sig = m_sig.takeFirst();
         m_mutex.unlock();
 
@@ -73,6 +74,6 @@ void SignatureThread::run()
         }
     }
 #else //HAVE_QGPGME
-    kWarning(5001) << "No QGPGME support.";
+    qCWarning(KGET_DEBUG) << "No QGPGME support.";
 #endif //HAVE_QGPGME
 }
